%global p_vendor          upenn
%define _name             openssl
%global debug_package     %{nil}
%global __os_install_post %{nil}

%if "%{_os}" == "aix"
  %{!?_aix: %global _aix 1}
  %define __patch       /opt/freeware/bin/patch
%endif

%if 0%{?p_vendor:1}
  %global _orig_prefix    %{_prefix}
  %global name_prefix     %{p_vendor}-

  # Use the alternate locations for things.
  %define _lib            lib
  %global _sysconfdir     /usr/local/etc

  # Override _prefix last, so we can get the _real_* locations.
  %define _prefix         /usr/local
  %define _libdir         %{_prefix}/lib
  %global _mandir         %{_prefix}/share/man
%endif

# 11503 -- Don't provide un-namespaced libraries inside rpm database
#AutoReqProv:    0

Name:           %{?name_prefix}%{_name}
Version:        1.0.1q
Release:        7%{?dist}
Summary:        A general purpose cryptography library with TLS implementation
Group:          System Environment/Libraries
License:        OpenSSL
URL:            http://www.openssl.org/
Source0:        http://www.openssl.org/source/%{_name}-%{version}.tar.gz

# Allow Configure to respect the RPM_OPT_FLAGS environment variable,
# to work around problems with long options for GCC (--parameters, specifically)
Patch2:         openssl-1.0.0l-respect-rpm_opt_flags.patch

%if 0%{?_aix}
# Work-around for bash-isms in a Makefile, which ksh doesn't understand
Patch10:        openssl-1.0.0l-add-shell-to-engines_makefile.patch
# Work-around for the brain-dead way that Configure determines which
# program to use for resolving Makefile dependencies.
Patch11:        openssl-1.0.0l-use-gcc-instead-of-makedepend.patch
%endif

BuildRoot:      %{_tmppath}/%{_name}-%{version}-%{release}-root-%(%{__id_u} -n)

# AIX rpm 3.0.5 doesn't add an automatic provides of self, so we have to do it
# manually
%if 0%{?_aix}
Provides:       %{name} = %{version}-%{release}
%endif


%if 0%{?_aix}
BuildRequires:  diffutils
%else
BuildRequires:  /usr/bin/rename
BuildRequires:  /usr/bin/cmp
BuildRequires:  mktemp
Requires:       mktemp
%endif

BuildRequires:  perl
BuildRequires:  sed
BuildRequires:  gzip

%if 0%{?rhel} && 0%{?rhel} <= 5
BuildRequires:  openssl
Requires:       openssl
%endif

%if 0%{?rhel} && 0%{?rhel} >= 6
BuildRequires:  ca-certificates
Requires:       ca-certificates
%endif

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  openssl-certs
Requires:       openssl-certs
Requires:       coreutils
%endif

%if 0%{?suse_version} >= 1315
BuildRequires:  ca-certificates
Requires:       ca-certificates
Requires:       coreutils
%endif

%description
The OpenSSL toolkit provides support for secure communications between
machines. OpenSSL includes a certificate management tool and shared
libraries which provide various cryptographic algorithms and
protocols.

%prep
%setup -q -n %{_name}-%{version}
#%patch2 -p1 -b .opt_flags

%if 0%{?_aix}
%patch10 -p1 -b .shell
%patch11 -p1 -b .makedepend
%endif

%build

# Set basic PE build flags
#export CFLAGS="${CFLAGS} -I%{_includedir}"
export CFLAGS="${CFLAGS}"
export LDFLAGS=" ${LDFLAGS} -L%{_libdir}"
export CC="gcc"

%if 0%{?_aix}
export PATH="/opt/freeware/bin:%{_bindir}:${PATH}"
# Linking on AIX is hard. And full of spiders. Don't worry, we'll just do it static like:
# https://www.gnu.org/licenses/gcc-exception-3.1-faq.html
export CFLAGS="${CFLAGS} -static-libgcc"
# Make sure the linker knows what it's looking for on AIX:
# http://publib.boulder.ibm.com/infocenter/aix/v6r1/index.jsp?topic=%2Fcom.ibm.aix.cmds%2Fdoc%2Faixcmds3%2Fld.htm
export LDFLAGS="-Wl,-brtl ${LDFLAGS} -L/usr/linux/lib -L/opt/freeware/lib -L/usr/lib"
export RM="rm -f"
export RANLIB="/opt/freeware/bin/granlib"
export AR="/opt/freeware/bin/ar"
export RANDFILE="/tmp/rpm-$(od -N16 -tu /dev/random | awk 'NR==1 {print $2} {}')"
%endif

%if 0%{?rhel} || 0%{?suse_version}
# No joke, the Configure script *does* honor RPM_OPT_FLAGS.
# We're using that to add some upstream configuration options
# related to stack-smashing.
export RPM_OPT_FLAGS="${RPM_OPT_FLAGS} -Wa,--noexecstack -DPURIFY"
export LDFLAGS="${LDFLAGS} -Wl,-z,relro,-rpath,%{_libdir}"
%endif

# the Configure file can't figure out what os or arch it's dealing with
# so we get to pass it that information, i.e. the logic below
sslarch=%{_os}-%{_arch}
%ifarch %ix86
sslarch=linux-elf
if ! echo %{_target} | grep -q i686 ; then
  sslflags="no-asm 386"
fi
%endif
%ifarch ppc
sslarch=aix-gcc
%endif

# OpenSSL Configure doesn't honor CFLAGS or LDFLAGS as environment variables.
# Instead, those should be passed to Configure at the end of its options, as
# any unrecognized options are passed straight through to ${CC}. Defining
# --libdir ensures that we avoid the multilib (lib/ vs. lib64/) problem,
# since configure uses the existence of a lib64 directory to determine
# if it should install its own libs into a multilib dir. Yay OpenSSL!
./Configure \
  --prefix=%{_prefix} \
  --libdir=%{_lib} \
  --openssldir=%{_prefix}/ssl \
  shared \
  threads \
  ${sslarch} \
  ${sslflags} \
  enable-camellia \
  enable-seed \
  enable-tlsext \
  enable-rfc3779 \
  enable-cms \
  enable-md2 \
  no-mdc2 \
  no-rc5 \
  no-ec2m \
  no-gost \
  no-srp \
  no-ssl2 \
  no-ssl3 \
  ${CFLAGS} \
  ${LDFLAGS}

make depend
make

%install
%if 0%{?_aix}
export PATH=/opt/freeware/bin:%{_bindir}:$PATH
export RM="rm -f"
export RANLIB=/opt/freeware/bin/granlib
export AR=/opt/freeware/bin/ar
export CFLAGS=$RPM_OPT_FLAGS
%endif
rm -rf $RPM_BUILD_ROOT
%if 0%{?suse_version}
install -d $RPM_BUILD_ROOT/%{_prefix}/ssl/certs
%endif
install -d $RPM_BUILD_ROOT/%{_lib}
install -d $RPM_BUILD_ROOT/%{_bindir}
install -d $RPM_BUILD_ROOT/%{_includedir}
install -d $RPM_BUILD_ROOT/%{_libdir}
install -d $RPM_BUILD_ROOT/%{_mandir}
install -d $RPM_BUILD_ROOT/%{_libdir}/openssl

make INSTALL_PREFIX=$RPM_BUILD_ROOT install
mv $RPM_BUILD_ROOT%{_prefix}/ssl/man/* $RPM_BUILD_ROOT%{_mandir}/
rmdir $RPM_BUILD_ROOT%{_prefix}/ssl/man

( cd $RPM_BUILD_ROOT%{_mandir};
for manpage in man*/* ; do
    # If a manpage is a symlink, blow it away
    if [ -h ${manpage} ] ; then
        rm ${manpage}
    fi
    # Make sure all the manpages are gzip'd
    if [ -f ${manpage} ] ; then
        gzip ${manpage}
    fi
done )

# Link the OpenSSL ca-certificate bundle into our vendored SSL library location
%if 0%{?rhel} == 4
ln -s /usr/share/ssl/certs/ca-bundle.crt "${RPM_BUILD_ROOT}%{_prefix}/ssl/cert.pem"
%endif
%if 0%{?rhel} >= 5
ln -s /etc/pki/tls/certs/ca-bundle.crt "${RPM_BUILD_ROOT}%{_prefix}/ssl/cert.pem"
%endif

%if 0%{?suse_version} >= 1315
ln -s "$(readlink /etc/ssl/ca-bundle.pem)" "${RPM_BUILD_ROOT}%{_prefix}/ssl/cert.pem"
%endif

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%post
set -e
pushd $(mktemp -d) 2>&1 >/dev/null
pushd %{_prefix}/ssl/certs 2>&1 >/dev/null
find /etc/ssl/certs -type f -a -name '*pem' -print0 | xargs -0 --no-run-if-empty -n1 ln -sf
%{_bindir}/c_rehash . 2>&1 >/dev/null

%postun
# We only want to nuke these certs on uninstall Otherwise they will be removed
# immediately after they are created in the %post
if [ $1 == 0 ]; then
  set -e
  pushd $(mktemp -d) 2>&1 >/dev/null
  pushd %{_prefix}/ssl/certs 2>&1 >/dev/null
  find ./ -type l -delete
fi
%endif


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc FAQ LICENSE CHANGES NEWS INSTALL README
%doc doc/c-indentation.el doc/openssl.txt
%doc doc/openssl_button.html doc/openssl_button.gif
%doc doc/ssleay.txt
%dir %{_prefix}/ssl
%dir %{_prefix}/ssl/misc
%if 0%{?rhel}
%{_prefix}/ssl/cert.pem
%endif
%if 0%{?suse_version}
%dir %{_prefix}/ssl/certs
%endif
%if 0%{?suse_version} >= 1315
%{_prefix}/ssl/cert.pem
%endif
%{_prefix}/ssl/misc/*
%{_prefix}/include/openssl

%config(noreplace) %{_prefix}/ssl/openssl.cnf

# Make sure permissions are set correctly
# Taken from the centos vault spec file for openssl
%attr(0755,root,root) %{_bindir}/openssl
%attr(0755,root,root) %{_bindir}/c_rehash
%attr(0755,root,root) %{_libdir}/engines/*
%attr(0755,root,root) %{_libdir}/*.so.*
%attr(0644,root,root) %{_libdir}/*.a
%attr(0755,root,root) %{_libdir}/*.so
%attr(0644,root,root) %{_libdir}/pkgconfig/*.pc
%attr(0644,root,root) %{_mandir}/man1*/*
%attr(0644,root,root) %{_mandir}/man3*/*
%attr(0644,root,root) %{_mandir}/man5*/*
%attr(0644,root,root) %{_mandir}/man7*/*


%changelog
* Wed Dec  3 2015 Garick Hamlin <ghamlin@isc.upenn.edu> - 1.0.1q-7
- bump to 1.0.1p

* Wed Nov  4 2015 Garick Hamlin <ghamlin@isc.upenn.edu> - 1.0.1p-6
- bump to 1.0.1p

* Wed Nov  4 2015 Garick Hamlin <ghamlin@isc.upenn.edu> - 1.0.0s-3
- First Upenn package forked from pe-openssl 1.0.0s-1
